@@ -18,6 +18,13 @@ saveWidget <- function(widget, file, selfcontained = TRUE, libdir = NULL,
                        background = "white", title = class(widget)[[1]],
                        knitrOptions = list()) {
 
+  # Transform #RRGGBB/#RRGGBBAA colors to rgba(r,g,b,a) form, because the
+  # pound sign interferes with pandoc processing
+  if (grepl("^#", background, perl = TRUE)) {
+    bgcol <- grDevices::col2rgb(background, alpha = TRUE)
+    background <- sprintf("rgba(%d,%d,%d,%f)", bgcol[1,1], bgcol[2,1], bgcol[3,1], bgcol[4,1]/255)
+  }
+
   # convert to HTML tags
   html <- toHTML(widget, standalone = TRUE, knitrOptions = knitrOptions)
 
@@ -30,15 +37,10 @@ saveWidget <- function(widget, file, selfcontained = TRUE, libdir = NULL,
   # make it self-contained if requested
   if (selfcontained) {
 
-    # Save the file
-    # Include a title; pandoc 2.0 complains if you don't have one
-    pandoc_save_markdown(html, file = file, libdir = libdir,
-                         background = background, title = title)
-
-    if (!pandoc_available()) {
-      stop("Saving a widget with selfcontained = TRUE requires pandoc. For details see:\n",
-           "https://github.com/rstudio/rmarkdown/blob/master/PANDOC.md")
-    }
+    # write the html to a md file (pandoc 2.0 complains if you don't have a title)
+    write_md_for_pandoc(
+      html, file = file, libdir = libdir, background = background, title = title
+    )
 
     pandoc_self_contained_html(file, file)
     unlink(libdir, recursive = TRUE)
